@@ -52,6 +52,7 @@ DIFFUSION_TEMPLATE = """\t\t<h3 class="elem-title">Summary</h3>
 \t\t\t<li>Phase-encoding (PE) direction: {pedir}</li>
 \t\t\t<li>Susceptibility distortion correction: {sdc}</li>
 \t\t\t<li>Coregistration Transform: {coregistration}</li>
+\t\t\t<li>Denoising Method: {denoise_method}</li>
 \t\t\t<li>Denoising Window: {denoise_window}</li>
 \t\t\t<li>HMC Transform: {hmc_transform}</li>
 \t\t\t<li>HMC Model: {hmc_model}</li>
@@ -217,7 +218,9 @@ class DiffusionSummaryInputSpec(BaseInterfaceInputSpec):
     hmc_transform = traits.Str(mandatory=True, desc='transform used during HMC')
     hmc_model = traits.Str(desc='model used for hmc')
     b0_to_t1w_transform = traits.Enum("Rigid", "Affine", desc='Transform type for coregistration')
-    dwi_denoise_window = traits.Int(desc='window size for dwidenoise')
+    denoise_method = traits.Str(desc='method used for image denoising')
+    dwi_denoise_window = traits.Either(traits.Int(), traits.Str(),
+                                       desc='window size for dwidenoise')
     output_spaces = traits.List(desc='Target spaces')
     confounds_file = File(exists=True, desc='Confounds file')
     validation_reports = InputMultiObject(File(exists=True))
@@ -250,6 +253,7 @@ class DiffusionSummary(SummaryInterface):
             coregistration=self.inputs.b0_to_t1w_transform,
             hmc_transform=self.inputs.hmc_transform,
             hmc_model=self.inputs.hmc_model,
+            denoise_method=self.inputs.denoise_method,
             denoise_window=self.inputs.dwi_denoise_window,
             output_spaces=', '.join(self.inputs.output_spaces),
             confounds=re.sub(r'[\t ]+', ', ', conflist),
@@ -335,6 +339,13 @@ def plot_gradients(bvals, orig_bvecs, source_filenums, output_fname, final_bvecs
     qx, qy, qz = qvecs.T
     maxvals = qvecs.max(0)
     minvals = qvecs.min(0)
+    total_max = max(np.abs(maxvals).max(), np.abs(minvals).max())
+
+    def force_scaling(ax):
+        # trick to force equal aspect on all 3 axes
+        for direction in (-1, 1):
+            for point in np.diag(direction * total_max * np.array([1,1,1])):
+                ax.plot([point[0]], [point[1]], [point[2]], 'w')
 
     def add_lines(ax):
         labels = ['L', 'P', 'S']
@@ -371,6 +382,7 @@ def plot_gradients(bvals, orig_bvecs, source_filenums, output_fname, final_bvecs
     orig_ax.axis('off')
     orig_ax.set_title("Original Scheme")
     add_lines(orig_ax)
+    force_scaling(orig_ax)
     # Animate rotating the axes
     rotate_amount = np.ones(frames) * 180 / frames
     stay_put = np.zeros_like(rotate_amount)
@@ -476,9 +488,9 @@ from sub-1_dir-PA_dwi.nii.gz.
             formatted_indices = ", ".join(map(str, image_indices))
             plural = 's' if len(image_indices) > 1 else ''
             group_desc += [
-                "image{plural} {imgnums} from {img_name}".format(plural=plural,
-                                                                 imgnums=formatted_indices,
-                                                                 img_name=image_name),
+                "image{plural} {imgnums} from {img_name}".format(
+                    plural=plural, imgnums=formatted_indices,
+                    img_name=op.split(image_name)[-1]),
                 ", "]
         group_desc[-1] = ". "
         if len(image_list) > 1:
@@ -704,6 +716,8 @@ class _ReconPeaksReportInputSpec(BaseInterfaceInputSpec):
     mask_file = File(exists=True)
     background_image = File(exists=True)
     odf_rois = File(exists=True)
+    peaks_only = traits.Bool(False, usedefault=True,
+                             desc='only produce a peak directions report')
     subtract_iso = traits.Bool(False, usedefault=True,
                                desc='subtract isotropic component from ODFs')
 
@@ -732,6 +746,7 @@ class ReconPeaksReport(SimpleInterface):
             directions = np.load(self.inputs.directions_file)
         else:
             raise Exception('Requires either a mif file or fib file')
+
         odf_4d = odf_img.get_fdata()
         sphere = HemiSphere(xyz=directions.astype(np.float))
         if not isdefined(self.inputs.background_image) or self.inputs.background_image is None:
@@ -746,7 +761,7 @@ class ReconPeaksReport(SimpleInterface):
         self._results['out_report'] = peak_report
 
         # Plot ODFs in interesting regions
-        if isdefined(self.inputs.odf_rois):
+        if isdefined(self.inputs.odf_rois) and not self.inputs.peaks_only:
             odf_report = op.join(runtime.cwd, 'odf_report.png')
             odf_roi_plot(odf_4d, sphere, background_data, odf_report, self.inputs.odf_rois,
                          subtract_iso=self.inputs.subtract_iso,
